@@ -253,18 +253,22 @@ class PropertyAdderBot(ABC):
                             new_claim, *extra_reference.new_reference_props.values()
                         )
                         acted = True
-        with start_span(op="post_output_process"):
+        with start_span(
+            op="post_output_process", description="Post Output Process Hook"
+        ):
             if self.post_output_process_hook(output, item) and not acted:
                 acted = True
         if acted:
-            with start_span(op="pre_edit_process"):
+            with start_span(op="pre_edit_process", description="Pre Edit Process Hook"):
                 self.pre_edit_process_hook(output, item)
-            with start_span(op="edit_entity"):
+            with start_span(op="edit_entity", description="Edit Entity"):
                 item.editEntity(
                     summary=self._get_full_summary(item),
                     bot=True,
                 )
-            with start_span(op="post_edit_process"):
+            with start_span(
+                op="post_edit_process", description="Post Edit Process Hook"
+            ):
                 self.post_edit_process_hook(output, item)
         return acted
 
@@ -274,10 +278,10 @@ class PropertyAdderBot(ABC):
         :param item: The item to act on.
         :return: If any edits were made to the item.
         """
-        with start_transaction(op="act_on_item"):
-            with start_span(op="get_output"):
+        with start_transaction(op="act_on_item", name="Process Item"):
+            with start_span(op="get_output", description="Get Output"):
                 output = self.run_item(item)
-            with start_span(op="process_output"):
+            with start_span(op="process_output", description="Process Output"):
                 return self.process(output, item)
 
     def feed_items(self, items: Iterable[EntityPage]) -> None:
